@@ -3,7 +3,7 @@ our $AUTHORITY = 'cpan:GENE';
 
 # ABSTRACT: Parse the UCI Bach choral harmony data set
 
-our $VERSION = '0.0400';
+our $VERSION = '0.0401';
 
 use Moo;
 use strictures 2;
@@ -343,7 +343,7 @@ Music::BachChoralHarmony - Parse the UCI Bach choral harmony data set
 
 =head1 VERSION
 
-version 0.0400
+version 0.0401
 
 =head1 SYNOPSIS
 
@@ -443,25 +443,6 @@ identifier, title, key and list of events.  The event list is made of
 hash references with a B<notes> bit-string, B<bass> note, the
 B<accent> value and the resonating B<chord>.
 
-The dataset B<notes> bit-string is defined by position as follows:
-
-  0  => C
-  1  => C# or Db
-  2  => D
-  3  => D# or Eb
-  4  => E
-  5  => F
-  6  => F# or Gb
-  7  => G
-  8  => G# or Ab
-  9  => A
-  10 => A# or Bb
-  11 => B
-
-So if a C<C> note is present, the C<0>th bit will be set to C<1>,
-otherwise C<0>.  If a C<Bb> note is present, the C<10>th bit will be
-set, etc.
-
 =head2 search
 
   $songs = $bach->search( $k => $v ); # As in the SYNOPSIS above
